@@ -8,13 +8,11 @@ These need some refactoring.
 
 import urllib
 
-from tiddlyweb.filters import FilterError
 from tiddlyweb.model.bag import Bag
 from tiddlyweb.model.policy import \
         create_policy_check, UserRequiredError, ForbiddenError
 from tiddlyweb.store import NoBagError, StoreMethodNotImplemented
 from tiddlyweb.serializer import Serializer, NoSerializationError
-from tiddlyweb import control
 from tiddlyweb.web import util as web
 from tiddlyweb.web.sendtiddlers import send_tiddlers
 from tiddlyweb.web.http import HTTP400, HTTP404, HTTP415
@@ -80,8 +78,6 @@ def get_tiddlers(environ, start_response):
     bag. The information sent is dependent on the
     serialization chosen.
     """
-    filters = environ['tiddlyweb.filters']
-
     bag_name = _determine_bag_name(environ)
     bag = _get_bag(environ, bag_name)
 
@@ -89,14 +85,7 @@ def get_tiddlers(environ, start_response):
     # will raise exception if there are problems
     bag.policy.allows(usersign, 'read')
 
-    try:
-        tiddlers = control.filter_tiddlers_from_bag(bag, filters)
-    except FilterError, exc:
-        raise HTTP400('malformed filter: %s' % exc)
-    tmp_bag = Bag('tmp_bag', tmpbag=True)
-    tmp_bag.add_tiddlers(tiddlers)
-
-    return send_tiddlers(environ, start_response, tmp_bag)
+    return send_tiddlers(environ, start_response, bag)
 
 
 def list(environ, start_response):
